@@ -117,6 +117,7 @@ __all__ = (
     "DomainInfoTypeDef",
     "DomainInformationTypeDef",
     "DomainPackageDetailsTypeDef",
+    "DryRunResultsTypeDef",
     "DurationTypeDef",
     "EBSOptionsStatusTypeDef",
     "EBSOptionsTypeDef",
@@ -256,6 +257,7 @@ AdvancedSecurityOptionsInputTypeDef = TypedDict(
         "InternalUserDatabaseEnabled": bool,
         "MasterUserOptions": "MasterUserOptionsTypeDef",
         "SAMLOptions": "SAMLOptionsInputTypeDef",
+        "AnonymousAuthEnabled": bool,
     },
     total=False,
 )
@@ -274,6 +276,8 @@ AdvancedSecurityOptionsTypeDef = TypedDict(
         "Enabled": bool,
         "InternalUserDatabaseEnabled": bool,
         "SAMLOptions": "SAMLOptionsOutputTypeDef",
+        "AnonymousAuthDisableDate": datetime,
+        "AnonymousAuthEnabled": bool,
     },
     total=False,
 )
@@ -884,6 +888,15 @@ DomainPackageDetailsTypeDef = TypedDict(
     total=False,
 )
 
+DryRunResultsTypeDef = TypedDict(
+    "DryRunResultsTypeDef",
+    {
+        "DeploymentType": str,
+        "Message": str,
+    },
+    total=False,
+)
+
 DurationTypeDef = TypedDict(
     "DurationTypeDef",
     {
@@ -1717,6 +1730,7 @@ _OptionalUpdateElasticsearchDomainConfigRequestRequestTypeDef = TypedDict(
         "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
         "EncryptionAtRestOptions": "EncryptionAtRestOptionsTypeDef",
         "AutoTuneOptions": "AutoTuneOptionsTypeDef",
+        "DryRun": bool,
     },
     total=False,
 )
@@ -1733,6 +1747,7 @@ UpdateElasticsearchDomainConfigResponseTypeDef = TypedDict(
     "UpdateElasticsearchDomainConfigResponseTypeDef",
     {
         "DomainConfig": "ElasticsearchDomainConfigTypeDef",
+        "DryRunResults": "DryRunResultsTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
